|Build Status|

superprompt
===========

Prompting on steroids

.. |Build Status| image:: https://travis-ci.org/ddorn/superprompt.svg?branch=v1.2.0
   :target: https://travis-ci.org/ddorn/superprompt
